pub fn native() -> Result<LedgerSigner<TransportNativeHID>, Error>Expand description
Errors
Could fail to make the connection to the Ledger device
pub fn native() -> Result<LedgerSigner<TransportNativeHID>, Error>Could fail to make the connection to the Ledger device